//-----------------------------------------------------------------------------
//
//  $Logfile:: /Quake 2 Engine/Sin/code/ctf/ctf.cpp                           $
// $Revision:: 2                                                              $
//   $Author:: Aldie                                                          $
//     $Date:: 2/16/99 4:08p                                                  $
//
// Copyright (C) 1998 by Ritual Entertainment, Inc.
// All rights reserved.
//
// This source may not be distributed and/or modified without
// expressly written permission by Ritual Entertainment, Inc.
//
// $Log:: /Quake 2 Engine/Sin/code/ctf/ctf.cpp                                $
// 
// 2     2/16/99 4:08p Aldie
// 
// 1     2/11/99 1:38p Aldie
// 
// 3     10/10/98 3:37a Jimdose
// Began converting to Sin
// 
// 2     10/10/98 3:03a Jimdose
// Created file
// 
// 1     10/10/98 3:02a Jimdose
//
// DESCRIPTION:
// Game code for Capture the Flag.
//
// The original source for this code was graciously provided by Zoid and
// Id Software.  Many thanks!
//
// Original credits:
//
// Programming             - Dave 'Zoid' Kirsch
// Original CTF Art Design - Brian 'Whaleboy' Cozzens
// 

#include "g_local.h"
#include "ctf.h"
#include "ctf_player.h"

cvar_t *ctf;
cvar_t *ctf_forcejoin;
cvar_t *ctf_hardcorps_skin;
cvar_t *ctf_sintek_skin;

typedef struct ctfgame_s
   {
	int   team_hardcorps;
   int   team_sintek;
	int   total1, total2; // these are only set when going into intermission!
	float last_flag_capture;
	int   last_capture_team;
   } ctfgame_t;

ctfgame_t ctfgame;

static CTF_Flag_Hardcorps *hardcorps_flag;
static CTF_Flag_Sintek *sintek_flag;

qboolean techspawn = false;

void CTF_Init
   (
   void
   )

   {
   ctf						= gi.cvar("ctf", "1", CVAR_SERVERINFO);
	ctf_forcejoin			= gi.cvar("ctf_forcejoin", "", 0);
	ctf_hardcorps_skin	= gi.cvar("ctf_hardcorps_skin", "hc_skin", CVAR_SERVERINFO);
	ctf_sintek_skin		= gi.cvar("ctf_sintek_skin", "sintek_skin", CVAR_SERVERINFO);
   memset( &ctfgame, 0, sizeof( ctfgame ) );
	techspawn = false;
   }

void CTF_InitFlags
	(
	void
	)

	{
	int num = 0;
   
	// Find the flags
   if ( num = G_FindClass( 0, "CTF_Flag_Hardcorps" ) )
		hardcorps_flag = ( CTF_Flag_Hardcorps * )G_GetEntity( num );

   if ( num = G_FindClass( 0, "CTF_Flag_Sintek" ) )
		sintek_flag = ( CTF_Flag_Sintek * )G_GetEntity( num );

	// Check for errors
	if ( !hardcorps_flag )
		gi.error( "CTF: Hardcorps flag not found!\n" );

	if ( !sintek_flag )
		gi.error( "CTF: Sintek flag not found!\n" );
	}

qboolean CTF_CheckRules
   (
   void
   )
   
   {
	if ( capturelimit->value && 
		( ctfgame.team_hardcorps >= capturelimit->value || ctfgame.team_sintek >= capturelimit->value ) )
      {
		gi.bprintf (PRINT_HIGH, "Capturelimit hit.\n");
		return true;
	   }
	return false;
   }

void CTF_UpdateStats
   (
   Player *player
   )

   {
	int i;
	int p1, p2;

	
	if ( !hardcorps_flag  || !sintek_flag )
		{
		CTF_InitFlags();
		}
	
	// logo headers for the frag display
	player->client->ps.stats[STAT_CTF_TEAM1_HEADER] = gi.imageindex ("i_hc_logo");
	player->client->ps.stats[STAT_CTF_TEAM2_HEADER] = gi.imageindex ("i_st_logo");

  /*
	// if during intermission, we must blink the team header of the winning team
	if (level.intermissiontime && (level.framenum & 8)) { // blink 1/8th second
		// note that ctfgame.total[12] is set when we go to intermission
		if (ctfgame.team1 > ctfgame.team2)
			player->client->ps.stats[STAT_CTF_TEAM1_HEADER] = 0;
		else if (ctfgame.team2 > ctfgame.team1)
			player->client->ps.stats[STAT_CTF_TEAM2_HEADER] = 0;
		else if (ctfgame.total1 > ctfgame.total2) // frag tie breaker
			player->client->ps.stats[STAT_CTF_TEAM1_HEADER] = 0;
		else if (ctfgame.total2 > ctfgame.total1) 
			player->client->ps.stats[STAT_CTF_TEAM2_HEADER] = 0;
		else { // tie game!
			player->client->ps.stats[STAT_CTF_TEAM1_HEADER] = 0;
			player->client->ps.stats[STAT_CTF_TEAM2_HEADER] = 0;
		}
	}
   */

   /*
	// tech icon
	i = 0;
	player->client->ps.stats[STAT_CTF_TECH] = 0;
	while (tnames[i]) {
		if ((tech = FindItemByClassname(tnames[i])) != NULL &&
			player->client->pers.inventory[ITEM_INDEX(tech)]) {
			player->client->ps.stats[STAT_CTF_TECH] = gi.imageindex(tech->icon);
			break;
		}
		i++;
	}
   */

	// figure out what icon to display for team logos
	// three states:
	//   flag at base
	//   flag taken
	//   flag dropped
	p1 = gi.imageindex( "i_ctf_hcflag" );

	if ( hardcorps_flag )
      {
		if ( hardcorps_flag->edict->solid == SOLID_NOT )
         {
			// not at base
			// check if on enemy player
			p1 = gi.imageindex( "i_ctf_hcflagd" ); // default to dropped

			for ( i = 1; i <= maxclients->value; i++ )
            {
            if ( g_edicts[i].inuse && g_edicts[i].client ) 
               {
               Player *player;
               player = ( Player * )g_edicts[i].entity;

               if ( player->HasItem( "CTF_Flag_Hardcorps" ) )
                  {
                  // enemy has it
					   p1 = gi.imageindex( "i_ctf_hcflagt" );
					   break;
                  }
               }
            }
         }
      else if ( hardcorps_flag->spawnflags & DROPPED_ITEM )
         {
			p1 = gi.imageindex( "i_ctf_hcflagd" ); // must be dropped
         }
      }

  	p2 = gi.imageindex( "i_ctf_stflag" );

  	if ( sintek_flag )
      {
		if ( sintek_flag->edict->solid == SOLID_NOT )
         {
			// not at base
			// check if on enemy player
			p2 = gi.imageindex( "i_ctf_stflagd" ); // default to dropped

			for ( i = 1; i <= maxclients->value; i++ )
            {
            if ( g_edicts[i].inuse && g_edicts[i].client ) 
               {
               Player *player;
               player = ( Player * )g_edicts[i].entity;

               if ( player->HasItem( "CTF_Flag_Sintek" ) )
                  {
                  // enemy has it
					   p2 = gi.imageindex( "i_ctf_stflagt" );
					   break;
                  }
               }
            }
         }
      else if ( sintek_flag->spawnflags & DROPPED_ITEM )
         {
			p2 = gi.imageindex( "i_ctf_stflagd,tga" ); // must be dropped
         }
      }

	player->client->ps.stats[STAT_CTF_TEAM1_PIC] = p1;
	player->client->ps.stats[STAT_CTF_TEAM2_PIC] = p2;

   /*
   if (ctfgame.last_flag_capture && level.time - ctfgame.last_flag_capture < 5) {
		if (ctfgame.last_capture_team == CTF_TEAM1)
			if (level.framenum & 8)
				player->client->ps.stats[STAT_CTF_TEAM1_PIC] = p1;
			else
				player->client->ps.stats[STAT_CTF_TEAM1_PIC] = 0;
		else
			if (level.framenum & 8)
				player->client->ps.stats[STAT_CTF_TEAM2_PIC] = p2;
			else
				player->client->ps.stats[STAT_CTF_TEAM2_PIC] = 0;
	}
*/
   // Update the number of captures for each team
	player->client->ps.stats[STAT_CTF_TEAM1_CAPS] = ctfgame.team_hardcorps;
	player->client->ps.stats[STAT_CTF_TEAM2_CAPS] = ctfgame.team_sintek;

   
	player->client->ps.stats[STAT_CTF_FLAG_PIC] = 0;

   // if hardcorps player has the sintek flag
	if ( player->client->resp.ctf_team == CTF_TEAM_HARDCORPS &&
		player->HasItem( "CTF_Flag_Sintek" ) &&
		( level.framenum & 8 ) )
      {
      player->client->ps.stats[STAT_CTF_FLAG_PIC] = gi.imageindex( "i_ctf_stflag" );
      }

   // if sintek player has the hardcorps flag
	if ( player->client->resp.ctf_team == CTF_TEAM_SINTEK &&
		player->HasItem( "CTF_Flag_Hardcorps" ) &&
		( level.framenum & 8 ) )
      {
      player->client->ps.stats[STAT_CTF_FLAG_PIC] = gi.imageindex( "i_ctf_hcflag" );
      }

	player->client->ps.stats[STAT_CTF_JOINED_TEAM1_PIC] = 0;
	player->client->ps.stats[STAT_CTF_JOINED_TEAM2_PIC] = 0;
	
   if ( player->client->resp.ctf_team == CTF_TEAM_HARDCORPS )
		player->client->ps.stats[STAT_CTF_JOINED_TEAM1_PIC] = gi.imageindex( "i_ctfj" );
	else if (player->client->resp.ctf_team == CTF_TEAM_SINTEK )
		player->client->ps.stats[STAT_CTF_JOINED_TEAM2_PIC] = gi.imageindex( "i_ctfj" );


   /*player->client->ps.stats[STAT_CTF_ID_VIEW] = 0;
	if (player->client->resp.id_state)
		CTFSetIDView(player);
      */
   }


/*
================
SelectCTFSpawnPoint

go to a CTF point, but NOT the two points closest
to other players
================
*/
extern Entity *SelectFarthestDeathmatchSpawnPoint(	void );
extern Entity *SelectRandomDeathmatchSpawnPoint( void );
extern float	PlayersRangeFromSpot( Entity *spot );

Entity *SelectCTFSpawnPoint
   (
   edict_t *ent
   )

   {
	Entity 	*spot, *spot1, *spot2;
	int		count = 0;
	int		selection;
	float	   range, range1, range2;
	char	   *cname;
   int      num = 0;

   // Client is not in the START state, pick a random spot
	if ( ent->client->resp.ctf_state != CTF_STATE_START )
		if ( DM_FLAG( DF_SPAWN_FARTHEST ) )
			return SelectFarthestDeathmatchSpawnPoint ();
		else
			return SelectRandomDeathmatchSpawnPoint ();

   // Set the player to PLAYING state
	ent->client->resp.ctf_state = CTF_STATE_PLAYING;

	switch (ent->client->resp.ctf_team)
      {
	   case CTF_TEAM_HARDCORPS:
		   cname = "info_player_hardcorps";
		   break;
	   case CTF_TEAM_SINTEK:
   		cname = "info_player_sintek";
		   break;
	   default:
		   return SelectRandomDeathmatchSpawnPoint();
	   }

	spot = NULL;
	range1 = range2 = 99999;
	spot1 = spot2 = NULL;

	while( ( num = G_FindClass( num, cname ) ) != NULL )
      {
  		spot = G_GetEntity( num );

		count++;
		range = PlayersRangeFromSpot( spot );

		if ( range < range1 )
		   {
			range1 = range;
			spot1 = spot;
		   }
		else if ( range < range2 )
		   {
			range2 = range;
			spot2 = spot;
		   }
      }

	if ( !count )
		return SelectRandomDeathmatchSpawnPoint();

	if ( count <= 2 )
	   {
		spot1 = spot2 = NULL;
	   }
	else
      {
		count -= 2;
      }

	selection = rand() % count;

	spot = NULL;
   num = 0;
	do {
      num  = G_FindClass( num, cname );
  		spot = G_GetEntity( num );

		if (spot == spot1 || spot == spot2)
			selection++;

      }
   while(selection--);

	return spot;
   }

void CTF_ScoreboardMessage
   (
   Entity *ent,
   Entity *killer
   )

   {
   char	      entry[1024];
	char	      string[1400];
	int		   len;
	int		   i, j, k;
	int		   sorted[2][MAX_CLIENTS];
	int		   sortedscores[2][MAX_CLIENTS];
	int		   score, total[2], totalscore[2];
	int		   last[2];
	gclient_t	*cl;
	edict_t		*cl_ent;// sort the clients by team and score
   int         team;
	int         maxsize = 1000;
   Player      *client;

	total[0] = total[1] = 0;
	last[0] = last[1] = 0;
	totalscore[0] = totalscore[1] = 0;

	for (i=0 ; i<game.maxclients ; i++)
	   {
		cl_ent = g_edicts + 1 + i;

		if ( !cl_ent->inuse)
			continue;

		if ( game.clients[i].resp.ctf_team == CTF_TEAM_HARDCORPS )
			team = 0;
		else if ( game.clients[i].resp.ctf_team == CTF_TEAM_SINTEK )
			team = 1;
		else
			continue; // unknown team

		score = game.clients[i].resp.score;

		for ( j=0 ; j<total[team] ; j++ )
		   {
			if ( score > sortedscores[team][j] )
				break;
		   }

		for ( k=total[team] ; k>j ; k-- )
		   {
			sorted[team][k] = sorted[team][k-1];
			sortedscores[team][k] = sortedscores[team][k-1];
		   }

		sorted[team][j] = i;
		sortedscores[team][j] = score;
		totalscore[team] += score;
		total[team]++;
	   }

   *string = 0;
   len = 0;
/*
#define STAT_CTF_TECH				   7
#define STAT_CTF_ID_VIEW			   8
#define STAT_CTF_TEAM1_PIC			   11
#define STAT_CTF_TEAM1_CAPS			12
#define STAT_CTF_TEAM2_PIC			   13
#define STAT_CTF_TEAM2_CAPS			14
#define STAT_CTF_FLAG_PIC			   15
#define STAT_CTF_JOINED_TEAM1_PIC	16
#define STAT_CTF_JOINED_TEAM2_PIC	17
#define STAT_CTF_TEAM1_HEADER		   18
#define STAT_CTF_TEAM2_HEADER		   19
*/
   
   // Headers
   sprintf( string, 
      "if 18 xv -130 yv 88 pic 18 endif "    // team 1 header
		"xv -130 yv 100 string \"%4d/%-3d\" "  // team 1 total score 
		"xv -50 yv 92 num 12 "                 // team 1 num captures
		"if 19 xv 10 yv 88 pic 19 endif "      // team 2 header
		"xv 10 yv 100 string \"%4d/%-3d\" "    // team 2 total score
		"xv 80 yv 92 num 14 ",                 // team 2 num captures 
		totalscore[0], total[0],
		totalscore[1], total[1] );
	
   len = strlen(string);

   for (i=0 ; i<16 ; i++)
	   {
		if (i >= total[0] && i >= total[1])
			break; // we're done

      sprintf( entry, "yv %d ", 80 - i * 8 );
		if ( maxsize - len > strlen( entry ) )
         {
			strcat(string, entry);
			len = strlen(string);
		   }

		// left side
		if ( i < total[0] )
         {
			cl = &game.clients[sorted[0][i]];
			cl_ent = g_edicts + 1 + sorted[0][i];

			sprintf( entry + strlen( entry ),
   			      "xv -130 %s \"%3d %3d %-12.12s\" ",
			         ( cl_ent == ent->edict ) ? "string2" : "string",
			         cl->resp.score, 
			         ( cl->ping > 999 ) ? 999 : cl->ping, 
			         cl->pers.netname );

         client = (Player *)(Sentient *)cl_ent->entity;

         if ( client->HasItem( "CTF_Flag_Sintek" ) )
            {
				sprintf( entry + strlen( entry ), "xv -72 picn i_has_stflag " );
            }

			if ( maxsize - len > strlen( entry ) ) 
            {
				strcat( string, entry );
				len = strlen( string );
				last[0] = i;
			   }
		   }

      if ( i < total[1] )
         {
			cl = &game.clients[sorted[1][i]];
			cl_ent = g_edicts + 1 + sorted[1][i];

			sprintf( entry + strlen( entry ),
   			      "xv 10 %s \"%3d %3d %-12.12s\" ",
			         ( cl_ent == ent->edict ) ? "string2" : "string",
			         cl->resp.score, 
			         ( cl->ping > 999 ) ? 999 : cl->ping, 
			         cl->pers.netname );
      
         client = (Player *)(Sentient *)cl_ent->entity;

         if ( client->HasItem( "CTF_Flag_Hardcorps" ) )
            {
				sprintf( entry + strlen( entry ), "xv 66 picn i_has_hcflag " );
            }

         if ( maxsize - len > strlen( entry ) ) 
            {
				strcat( string, entry );
				len = strlen( string );
				last[1] = i;
			   }
		   }
      }

   gi.WriteByte (svc_layout);
	gi.WriteString (string);
   }


char *CTF_TeamName
	(
	int team
	)

	{
	switch (team)
		{
		case CTF_TEAM_HARDCORPS:
			return "HardCorps";
		case CTF_TEAM_SINTEK:
			return "Sintek";
		}
	return "Unknown";
	}

char *CTF_OtherTeamName
	(
	int team
	)

	{
	switch (team)
		{
		case CTF_TEAM_HARDCORPS:
			return "Sintek";
		case CTF_TEAM_SINTEK:
			return "HardCorps";
		}
	return "UKNOWN";
	}

int CTF_OtherTeam
	(
	int team
	)

	{
	switch (team)
		{
		case CTF_TEAM_HARDCORPS:
			return CTF_TEAM_SINTEK;
		case CTF_TEAM_SINTEK:
			return CTF_TEAM_HARDCORPS;
		}
	return -1; // invalid value
	}


// FLAGS
CLASS_DECLARATION( InventoryItem, CTF_Flag, NULL );

Event EV_Flag_Reset( "resetflag" );

ResponseDef CTF_Flag::Responses[] =
	{
      { &EV_Item_Pickup,      (Response)CTF_Flag::PickupFlag },
      { &EV_Flag_Reset,       (Response)CTF_Flag::ResetFlag },
      { NULL, NULL }
	};

CTF_Flag::CTF_Flag
	(
	)

	{
	modelIndex( "ctf_flag_sintek.def" );
	modelIndex( "ctf_flag_hardcorps.def" );
	}

void CTF_Flag::ResetFlag
   (
   Event *ev
   )

   {
   // The autoreturn time has timed out.  This should be a dropped flag,
   // remove it and respawn back at the home base.
  
   assert( spawnflags & DROPPED_PLAYER_ITEM );

   if ( ctf_team == CTF_TEAM_HARDCORPS )
      hardcorps_flag->PostEvent( EV_Item_Respawn, FRAMETIME );
   else if ( ctf_team == CTF_TEAM_SINTEK )
      sintek_flag->PostEvent( EV_Item_Respawn, FRAMETIME );

   if ( !( spawnflags & DROPPED_PLAYER_ITEM ) )
      {
      gi.dprintf( "CTF_Flag::ResetFlag: Tried to reset a non-dropped flag\n" );
      return;
      }

   gi.bprintf( PRINT_HIGH, "The %s flag has returned!\n", CTF_TeamName( ctf_team ) );
   PostEvent( EV_Remove, 0 );
   }

void CTF_Flag::PickupFlag 
   (
   Event *ev
   )

   {
   Player   *player;
   str      enemy_flag, realname;
   Item     *item;
   Entity   *other;
   edict_t  *ent;
   int      i;

   other = ev->GetEntity( 1 );

   if ( !other->isClient() )
      return;

   player = (Player *)(Sentient *)other;

    // Figure out the enemy flag
   if ( ctf_team == CTF_TEAM_HARDCORPS ) 
      {
      enemy_flag = "CTF_Flag_Sintek";
      }
   else 
      {
      enemy_flag = "CTF_Flag_Hardcorps";
      }

   if ( player->client->resp.ctf_team == ctf_team ) // Player touched his own flag
      {
      if ( !( spawnflags & ( DROPPED_ITEM|DROPPED_PLAYER_ITEM ) ) )  // This flag was not dropped, so it's at home base
         { 
         if ( player->FindItem( enemy_flag.c_str() ) ) // Check to see if player has enemy's flag
            {
            // Player has the enemy flag and he just touched his team's flag, so he just scored
            gi.bprintf( PRINT_HIGH, "%s captured the %s flag!\n", other->client->pers.netname, CTF_OtherTeamName( ctf_team ) );

            // Take the enemy flag away from the player
            player->takeItem( enemy_flag.c_str(), 1 );

				if ( !hardcorps_flag || !sintek_flag )
					CTF_InitFlags();

            // Respawn the enemy's flag at it's home base
            if ( enemy_flag == "CTF_Flag_Hardcorps" )
               hardcorps_flag->PostEvent( EV_Item_Respawn, FRAMETIME );
            else if ( enemy_flag == "CTF_Flag_Sintek" )
               sintek_flag->PostEvent( EV_Item_Respawn, FRAMETIME );
            
            // Increment the team score
            if ( ctf_team == CTF_TEAM_HARDCORPS )
			   	ctfgame.team_hardcorps++;
				else
					ctfgame.team_sintek++;

            // Player gets a bonus score for capture
            other->client->resp.score += CTF_CAPTURE_BONUS;

            // Team bonus awards
           	for( i = 0; i < maxclients->value; i++ )
         		{
		         ent = &g_edicts[ i + 1 ];
		         
               if ( !ent->inuse || !ent->client || !ent->entity )
			         {
			         continue;
			         }

               // Team members get a bonus as well
               if ( ent->client->resp.ctf_team == other->client->resp.ctf_team )
                  {
						if ( ent != other->edict )
							ent->client->resp.score += CTF_TEAM_BONUS;
                  }
                  // TODO: Put in assists
               }
            }
         }
      else // Player touched his own flag that has been dropped, return it to his home base
         {
         if ( ctf_team == CTF_TEAM_HARDCORPS )
				{
            hardcorps_flag->PostEvent( EV_Item_Respawn, FRAMETIME );
				}
         else if ( ctf_team == CTF_TEAM_SINTEK )
				{
            sintek_flag->PostEvent( EV_Item_Respawn, FRAMETIME );
				}
         
         PostEvent( EV_Remove, 0 );
         
         gi.bprintf( PRINT_HIGH, "%s returned the %s flag!\n", other->client->pers.netname, CTF_TeamName( ctf_team ) );

         // Add in the recovery bonus score
         other->client->resp.score += CTF_RECOVERY_BONUS;
         }
      }
   else // Player touched enemy flag, pick it up
      {
		int groupindex;
		int tri_num;
		Vector orient;

      gi.bprintf( PRINT_HIGH, "%s got the %s flag!\n",other->client->pers.netname, CTF_TeamName( ctf_team ) );
      item = player->giveItem( getClassname(), 1, icon_index );

      if ( !item )
         {
         return;
         }
		
		// Attach flag to player
		if	( gi.GetBoneInfo( player->edict->s.modelindex, "pack", &groupindex, &tri_num, orient.vec3() ) )
			{
			Vector org;

			org = Vector( "0 0 -32" );

			item->showModel();
			item->setOrigin( org );
			item->attach( player->entnum, groupindex, tri_num, orient );
			}
		else
			{
			gi.dprintf( "attach failed\n" );
			}

      // Pickup sound
	   realname = GetRandomAlias( "snd_pickup" );
      if ( realname.length() > 1 )
         {
         player->sound( realname, 1, CHAN_ITEM, ATTN_NORM );
         }

   	item->CancelEventsOfType( EV_Item_DropToFloor );
	   item->CancelEventsOfType( EV_Item_Respawn );
      item->CancelEventsOfType( EV_FadeOut );

		if ( spawnflags & ( DROPPED_ITEM|DROPPED_PLAYER_ITEM ) )
			{
	      // Remove this dropped flag because a player just picked it up
			PostEvent( EV_Remove, 0 );
			}
		else
			{
			hideModel();
			setSolidType( SOLID_NOT );
			}
	   }
   }
   

CLASS_DECLARATION( CTF_Flag, CTF_Flag_Hardcorps, "ctf_flag_hardcorps" )

ResponseDef CTF_Flag_Hardcorps::Responses[] =
	{
		{ NULL, NULL }
	};

CTF_Flag_Hardcorps::CTF_Flag_Hardcorps
	(
	)

	{
   setModel( "ctf_flag_hardcorps_w.def" );
   ctf_team = CTF_TEAM_HARDCORPS;
	}


CLASS_DECLARATION( CTF_Flag, CTF_Flag_Sintek, "ctf_flag_sintek" )

ResponseDef CTF_Flag_Sintek::Responses[] =
	{
		{ NULL, NULL }
	};

CTF_Flag_Sintek::CTF_Flag_Sintek
	(
	)

	{
   setModel( "ctf_flag_sintek_w.def" );
   ctf_team = CTF_TEAM_SINTEK;
   }



CLASS_DECLARATION( InventoryItem, CTF_Tech, NULL );

Event EV_Tech_Timeout( "tech_timeout" );

ResponseDef CTF_Tech::Responses[] =
	{
      { &EV_Tech_Timeout, ( Response )CTF_Tech::Timeout },
		{ NULL, NULL }
	};

// TECH - 1 of each type is created at the beginning of the level, and
// it is respawned near the deathmatch starting locations.
CTF_Tech::CTF_Tech
   (
   )

   {
   Vector org, forward;

   org = FindSpawnLocation();
   org[2] += 16;
   setOrigin( org );
   worldorigin.copyTo(edict->s.old_origin);

   setMoveType( MOVETYPE_TOSS );
   
   angles[0] = 0;
	angles[1] = rand() % 360;
	angles[2] = 0;
   setAngles( angles );

   AngleVectors (angles.vec3(), forward.vec3(), NULL, NULL);
   
   // Throw the tech up and out
   velocity = forward * 100;
	velocity[2] = 350;

   // Techs don't respawn
	setRespawn( false );

	edict->s.effects |= EF_ROTATE;

   PostEvent( EV_Tech_Timeout, CTF_TECH_TIMEOUT );
   }

void CTF_Tech::HasTechMsg
   (
   edict_t *who
   )

   {
	if ( level.time - who->client->resp.ctf_lasttechmsg > 2 )
      {
      gi.centerprintf( who, "jcx jcy string \"You already have a TECH powerup\"" );
		who->client->resp.ctf_lasttechmsg = level.time;
	   }
   }


qboolean CTF_Tech::Pickupable 
   (
   Entity *other
   )

   {
 	if ( !other->isSubclassOf( Sentient ) )
		{
		return false;
		}
   else
      {
      Sentient *sent;
      Item     *item;

      sent = ( Sentient * )other;
      item = sent->HasItemOfSuperclass( getSuperclass() );
      if ( item )
         {
         HasTechMsg( other->edict );
         return false;
         }
      }
   return true;
   }

void CTF_Tech::Pickup
   (
   Event *ev 
   )

   {
   Entity   *other;
   Item     *item;

   other = ev->GetEntity( 1 );

   if ( !other->isClient() )
      return;

   // Try to give the tech to the player
   item = ItemPickup( other );

   if ( item )
      {
      // Cancel the timeout so it doesn't get removed from the player
      item->CancelEventsOfType( EV_Tech_Timeout );
      // Don't need this one anymore, remove it
      PostEvent( EV_Remove, 0 );
      }
   }

Vector CTF_Tech::FindSpawnLocation
   (
   void
   )

   {
	Entity *spot = NULL;
	int i = rand() % 16;
   int num = 0;

   // Find a location from the deathmatch spawn points

   while( i-- ) 
      {
      num = G_FindClass( num, "info_player_deathmatch" );
      }

   if ( !num )
      num = G_FindClass( num, "info_player_deathmatch" );

   spot = G_GetEntity( num );
	return spot->worldorigin;
   }

void CTF_Tech::Timeout
   (
   Event *ev
   )

   {
   Entity      *ent;
   ClassDef    *cls;

   cls = getClassForID( getClassname() );
   ent = ( Entity * )cls->newInstance();

   // this tech has been idle and timed out, remove it and create another one.
   PostEvent( EV_Remove, 0 );
   }

CLASS_DECLARATION( CTF_Tech, CTF_Tech_Regeneration, "ctf_tech_regeneration" )

Event EV_Tech_Regenerate( "tech_regenerate" );

ResponseDef CTF_Tech_Regeneration::Responses[] =
	{
		{ &EV_Tech_Regenerate, (Response)CTF_Tech_Regeneration::Regenerate },
		{ NULL, NULL }
	};

void CTF_Tech_Regeneration::Regenerate
	(
	Event *ev
	)

	{
	// Regenerate the owner
	if ( owner )
		{
		if ( owner->health < CTF_TECH_REGENERATION_HEALTH )
			{
			owner->health += 5;
			
			if ( owner->health > CTF_TECH_REGENERATION_HEALTH )
				{
				owner->health = CTF_TECH_REGENERATION_HEALTH;
				}
			}
		}

	PostEvent( EV_Tech_Regenerate, 5 );
	}

CTF_Tech_Regeneration::CTF_Tech_Regeneration
   (
   void
   )

   {
   setModel( "ctf_regen.def" );
   showModel();

	CancelEventsOfType( EV_Tech_Regenerate );
	PostEvent( EV_Tech_Regenerate, 5 );
   }

CLASS_DECLARATION( CTF_Tech, CTF_Tech_Double, "ctf_tech_double" )

ResponseDef CTF_Tech_Double::Responses[] =
	{
		{ NULL, NULL }
	};


CTF_Tech_Double::CTF_Tech_Double
   (
   void
   )

   {
   setModel( "ctf_double.def" );
   showModel();
   }

CLASS_DECLARATION( CTF_Tech, CTF_Tech_Half, "ctf_tech_half" )

ResponseDef CTF_Tech_Half::Responses[] =
	{
		{ NULL, NULL }
	};


CTF_Tech_Half::CTF_Tech_Half
   (
   void
   )

   {
   setModel( "ctf_half.def" );
   showModel();
   }

/*****************************************************************************/
/*SINED info_player_sintek (1 0 0) (-16 -16 0) (16 16 64)

The starting point for a member of team sintek when the first join
the game.
/*****************************************************************************/

/*****************************************************************************/
/*SINED info_player_hardcorps (1 0 0) (-16 -16 0) (16 16 64)

The starting point for a member of team sintek when the first join
the game.
/*****************************************************************************/
